package VMOMI::HostLockdownMode;
use parent 'VMOMI::SimpleType';

use strict;
use warnings;

1;
